import requests

class CryptoChecker:
    def __init__(self):
        self.base_url = "https://api.coingecko.com/api/v3"

    def get_price(self, crypto_name):
        url = f"{self.base_url}/simple/price?ids={crypto_name}&vs_currencies=usd"
        response = requests.get(url)
        data = response.json()
        if crypto_name in data:
            return data[crypto_name]['usd']
        else:
            return None



from setuptools import setup, find_packages

setup(
    name='crypto-checker',
    version='1.0.3',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    author='0xbichain',
    author_email='author@mahaka.net',
    description='A simple crypto price checker using CoinGecko API',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/0xbichain/crypto-checker',
    project_urls={
        'Source': 'https://github.com/0xbichain/crypto-checker',
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    python_requires='>=3.6',
)
